@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_OBJECT_H
 #define LIBTORRENT_OBJECT_H
 
@@ -112,7 +76,7 @@ public:
   Object& operator=(const Object& b);
 
   // TODO: Move this out of the class namespace, call them
-  // make_object_. 
+  // make_object_.
   static Object       create_empty(type_type t);
   static Object       create_value()  { return Object(value_type()); }
   static Object       create_string() { return Object(string_type()); }
@@ -128,7 +92,9 @@ public:
   template <typename ForwardIterator>
   static Object       create_list_range(ForwardIterator first, ForwardIterator last);
 
-  static Object       from_list(const list_type& src) { Object tmp; tmp.m_flags = TYPE_LIST; new (&tmp._list()) list_type(src); return tmp; }
+  static const char*  type_to_c_str(type_type t);
+
+  static Object       from_list(const list_type& src);
 
   // Clear should probably not be inlined due to size and not being
   // optimized away in pretty much any case. Might not work well in
@@ -246,8 +212,8 @@ public:
   static void         swap_same_type(Object& left, Object& right) noexcept;
 
  private:
-  bool                check(map_type::const_iterator itr, type_type t) const { return itr != _map().end() && itr->second.type() == t; }
-  void                check_throw(type_type t) const                         { if (t != type()) throw bencode_error("Wrong object type."); }
+  bool                check(map_type::const_iterator itr, type_type t) const;
+  void                check_throw(type_type t) const;
 
   template <typename T> void check_value_throw(const char* err_msg) const;
 
@@ -349,8 +315,8 @@ Object::Object(const Object& b) :
   switch (type()) {
   case TYPE_NONE:
   case TYPE_RAW_BENCODE:
-  case TYPE_RAW_STRING: 
-  case TYPE_RAW_LIST: 
+  case TYPE_RAW_STRING:
+  case TYPE_RAW_LIST:
   case TYPE_RAW_MAP:
   case TYPE_VALUE:       t_pod = b.t_pod; break;
   case TYPE_STRING:      new (&_string()) string_type(b._string()); break;
@@ -446,6 +412,31 @@ Object::create_list_range(ForwardIterator first, ForwardIterator last) {
   Object tmp; tmp.m_flags = TYPE_LIST; new (&tmp._list()) list_type(first, last); return tmp;
 }
 
+inline const char*
+Object::type_to_c_str(type_type t) {
+  switch (t) {
+  case TYPE_NONE:        return "none";
+  case TYPE_RAW_BENCODE: return "raw_bencode";
+  case TYPE_RAW_STRING:  return "raw_string";
+  case TYPE_RAW_LIST:    return "raw_list";
+  case TYPE_RAW_MAP:     return "raw_map";
+  case TYPE_VALUE:       return "value";
+  case TYPE_STRING:      return "string";
+  case TYPE_LIST:        return "list";
+  case TYPE_MAP:         return "map";
+  case TYPE_DICT_KEY:    return "dict_key";
+  default:               return "invalid";
+  }
+}
+
+inline Object
+Object::from_list(const list_type& src) {
+  Object tmp;
+  tmp.m_flags = TYPE_LIST;
+  new (&tmp._list()) list_type(src);
+  return tmp;
+}
+
 inline void
 Object::clear() {
   switch (type()) {
@@ -489,6 +480,17 @@ object_equal(const Object& left, const Object& right) {
   }
 }
 
+inline bool
+Object::check(map_type::const_iterator itr, type_type t) const {
+  return itr != _map().end() && itr->second.type() == t;
+}
+
+inline void
+Object::check_throw(type_type t) const {
+  if (t != type())
+    throw bencode_error("Wrong object type: expected: " + std::string(type_to_c_str(t)) + " actual: " + std::string(type_to_c_str(type())));
+}
+
 template <typename T>
 inline void
 Object::check_value_throw(const char* err_msg) const {
