@@ -9,6 +9,7 @@
 namespace torrent {
 
 // Make sure you seed srandom and srand48 if available.
+void                initialize_main_thread()LIBTORRENT_EXPORT;
 void                initialize() LIBTORRENT_EXPORT;
 
 // Clean up and close stuff. Stopping all torrents and waiting for
@@ -18,9 +19,7 @@ void                cleanup() LIBTORRENT_EXPORT;
 bool                is_inactive() LIBTORRENT_EXPORT;
 bool                is_initialized() LIBTORRENT_EXPORT;
 
-utils::Thread*      main_thread() LIBTORRENT_EXPORT;
-
-void                set_main_thread_slots(std::function<void()> do_work, std::function<uint64_t()> next_timeout) LIBTORRENT_EXPORT;
+void                set_main_thread_slots(std::function<void()> do_work) LIBTORRENT_EXPORT;
 
 ChunkManager*       chunk_manager() LIBTORRENT_EXPORT;
 ClientList*         client_list() LIBTORRENT_EXPORT;
@@ -28,8 +27,6 @@ ConnectionManager*  connection_manager() LIBTORRENT_EXPORT;
 FileManager*        file_manager() LIBTORRENT_EXPORT;
 ResourceManager*    resource_manager() LIBTORRENT_EXPORT;
 
-tracker::DhtController* dht_controller() LIBTORRENT_EXPORT;
-
 uint32_t            total_handshakes() LIBTORRENT_EXPORT;
 
 Throttle*           down_throttle_global() LIBTORRENT_EXPORT;
@@ -40,9 +37,6 @@ const Rate*         up_rate() LIBTORRENT_EXPORT;
 
 const char*         version() LIBTORRENT_EXPORT;
 
-// Disk access tuning.
-uint32_t            hash_queue_size() LIBTORRENT_EXPORT;
-
 using DList        = std::list<Download>;
 using EncodingList = std::list<std::string>;
 
@@ -70,6 +64,6 @@ Download            download_find(const std::string& infohash) LIBTORRENT_EXPORT
 uint32_t            download_priority(Download d) LIBTORRENT_EXPORT;
 void                download_set_priority(Download d, uint32_t pri) LIBTORRENT_EXPORT;
 
-}
+} // namespace torrent
 
 #endif
