@@ -13,10 +13,10 @@ namespace torrent {
 
 class LIBTORRENT_EXPORT signal_bitfield {
 public:
-  typedef uint32_t               bitfield_type;
-  typedef std::function<void ()> slot_type;
+  using bitfield_type = uint32_t;
+  using slot_type     = std::function<void()>;
 
-  static const unsigned int max_size = 32;
+  static constexpr unsigned int max_size = 32;
 
   signal_bitfield() = default;
 
@@ -36,6 +36,6 @@ private:
   std::atomic<bitfield_type>   m_bitfield{0};
 };
 
-}
+} // namespace torrent
 
 #endif
